.. highlight:: shell

============
Installation
============


Stable release
--------------

If you use anaconda_ to manage your Python environment, run this command in your
terminal:

.. code-block:: console

    $ conda install -c conda-forge specutils

Otherwise, the recommended method is using pip_:

.. code-block:: console

    $ pip install specutils

If you don't have pip_ installed, this `Python installation guide`_ can guide
you through the process.

These are the preferred methods to install Specutils, as they will always
install the most recent stable release.


.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/
.. _anaconda: https://www.anaconda.com/


From sources
------------

The sources for Specutils can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/astropy/specutils

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/astropy/specutils/tarball/main

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/astropy/specutils
.. _tarball: https://github.com/astropy/specutils/tarball/main
